import 'package:flutter/material.dart';
import 'package:firebase_core/firebase_core.dart';
import 'package:tidi_quiz/data/database_service.dart';
import 'package:tidi_quiz/models/questionmodel.dart';
import './pages/admin_page.dart';
import './pages/start_page.dart';
import 'data/firebase_options.dart';
import 'quiz_widgets/quiz.dart';
import 'quiz_widgets/result.dart';
import 'pages/start_quiz_page.dart';

/// The main function for starting the application.
void main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await Firebase.initializeApp(
    options: DefaultFirebaseOptions.currentPlatform,
  );

  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  List<QuestionModel> quizModelList = [];
  var quizDbHandler = QuizDBHandler();

  @override
  initState() {
    super.initState();
    quizDbHandler.getQuizData().then((value) => quizModelList = value);
  }

  // This widget is the root of the application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      routes: <String, WidgetBuilder>{
        '/': (context) => const StartPage(),
        '/admin': (context) => const AdminPage(),
        '/startquiz': (context) => const StartQuiz(),
        '/quiz': (context) => Quiz(quizModelList),
        '/result': (context) => const Result(),
      },
      debugShowCheckedModeBanner: false,
    );
  }
}
