import 'package:flutter/material.dart';
import 'package:tidi_quiz/models/result_arguments.dart';

import 'score.dart';
import 'theme.dart';

/// UI-element used to display the result of a finished quiz.
class Result extends StatefulWidget {
  const Result({Key? key}) : super(key: key);

  @override
  State<Result> createState() => _ResultState();
}

class _ResultState extends State<Result> {
  /// Generates resulttext based on a given score.
  _generateResultText(int score) {
    String resultText;

    if (score == 40) {
      resultText = "Alt riktig!";
    } else if (score == 30) {
      resultText = "Nesten alt riktig!";
    } else if (score == 20) {
      resultText = "To riktige svar!";
    } else if (score == 10) {
      resultText = "Ett riktig svar!";
    } else {
      resultText = "Dessverre ingen riktige.";
    }

    return resultText;
  }

  /// Navigates back to the root routing.
  void resetAndPopNavigator(context) {
    Navigator.popUntil(context, ModalRoute.withName('/'));
  }

  @override
  Widget build(BuildContext context) {
    ///Extracts the arguments passed on via the routing from [Quiz].
    var score = ModalRoute.of(context)!.settings.arguments as ResultArguments;

    var resultText = _generateResultText(score.totalScore);

    return Scaffold(
      extendBodyBehindAppBar: true,
      appBar: CommonAppbar('Result'),
      body: Container(
        constraints: const BoxConstraints.expand(),
        decoration: const BoxDecoration(
          image: DecorationImage(
              image: AssetImage("assets/images/app_background.png"),
              fit: BoxFit.cover),
        ),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Expanded(
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  const Image(
                    width: 103,
                    height: 94,
                    image: AssetImage("assets/images/flame.png"),
                  ),
                  const SizedBox(height: 30),
                  Text(
                    resultText,
                    style: const TextStyle(
                        fontSize: 36, fontWeight: FontWeight.bold),
                    textAlign: TextAlign.center,
                  ),
                  const SizedBox(height: 50),
                  Score(score.totalScore.toString()),
                  const SizedBox(height: 30),
                  SizedBox(
                    width: 256,
                    height: 67,
                    child: ElevatedButton(
                      child: const Text("Ta quiz på nytt"),
                      style: ElevatedButton.styleFrom(
                          textStyle: const TextStyle(fontSize: 28),
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(35)),
                          primary: const Color(0xFF283593),
                          onPrimary: Colors.white),
                      onPressed: () => resetAndPopNavigator(context),
                    ),
                  )
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
