import 'dart:async';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

/// UI-element which implements a [Timer] for displaying a timer with the remaining time left.
class TimerWidget extends StatefulWidget {
  const TimerWidget({Key? key}) : super(key: key);

  @override
  State<TimerWidget> createState() => _TimerWidgetState();
}

class _TimerWidgetState extends State<TimerWidget> {
  static const maxSeconds = 60;
  int seconds = maxSeconds;
  Timer? timer;

  /// Starts the timer
  void _startTimer() {
    timer = Timer.periodic(const Duration(seconds: 1), (_) => _updateSeconds());
  }

  /// Updates the second value displayed by the widget.
  void _updateSeconds() {
    (seconds <= 0) || !mounted ? timer?.cancel() : setState(() => seconds--);
  }

  @override
  void initState() {
    super.initState();
    _startTimer();
  }

  @override
  Widget build(BuildContext context) {
    _updateSeconds();
    return Container(
      width: double.infinity,
      margin: const EdgeInsets.all(10),
      child: Column(
        children: [
          const Icon(IconData(0xee2a, fontFamily: 'MaterialIcons')),
          Text(seconds.toString()),
        ],
      ),
    );
  }
}
